BoxJsonConverter Type
Serializes a Box as its origin and axis components with System.Text.Json.
Constructors
| Constructor |
Description
|
|
|
Serializes a Box as its origin and axis components with System.Text.Json.
| Constructor |
Description
|
|
|