Line3DJsonConverter Type
Serializes a Line3D as its start and end coordinates with System.Text.Json.
Constructors
| Constructor |
Description
|
|
|
Serializes a Line3D as its start and end coordinates with System.Text.Json.
| Constructor |
Description
|
|
|