NPlaneJsonConverter Type
Serializes an NPlane as its origin and normal components with System.Text.Json.
Constructors
| Constructor |
Description
|
|
|
Serializes an NPlane as its origin and normal components with System.Text.Json.
| Constructor |
Description
|
|
|