OffsetDirection Type
Holds the offset directions at a vertex. `prevInPlane` is the unit vector in the local plane pointing perpendicular to the previous segment, `nextInPlane` is the unit vector in the local plane pointing perpendicular to the next segment, `perpDir` is the unit vector perpendicular to the local plane made by the adjacent segments.
Record fields
| Record Field |
Description
|
|
The in-plane unit direction perpendicular to the next segment.
|
The unit direction perpendicular to the plane of the adjacent segments.
|
|
|
The in-plane unit direction perpendicular to the previous segment.
|
Euclid