Pnt Type
A struct containing 3 floats, representing an immutable 3D point. X, Y, and Z. A 3D point represents a location in space, but not direction. (use Vec for that.) (2D Points are called 'Pt' )
Record fields
| Record Field |
Description
|
Full Usage:
X
Field type: float
|
The field holding the X part of this 3D point.
|
Full Usage:
Y
Field type: float
|
The field holding the Y part of this 3D point.
|
Full Usage:
Z
Field type: float
|
The field holding the Z part of this 3D point.
|
Constructors
| Constructor |
Description
|
|
Create a new 3D point form X, Y, and Z coordinates. When compiled in DEBUG or with CHECK_EUCLID symbol defined, this constructor checks for NaN and Infinity values and raises an exception if any are found. This check is skipped in release mode for performance reasons.
|
Instance members
| Instance member |
Description
|
Full Usage:
this.AsFSharpCode
Returns: string
|
Format 3D point into an F# code string that can be used to recreate the point.
|
Full Usage:
this.AsString
Returns: string
|
Format 3D point into string with nice floating point number formatting of X, Y and Z But without full type name as in pt.ToString()
|
Euclid