Logo Euclid

PPlane Type

A struct containing one 3D point and three 3D unit vectors, representing an immutable parametrized plane or frame with unitized X, Y and Z Direction. Internally it is stored as 12 floats (the Origin point coordinates and the three axis vector components), just like the Box type. The Origin, Xaxis, Yaxis and Zaxis properties reconstruct the Pnt and UnitVec on demand. This struct is called 'PPlane'; the other plane 'NPlane' refers to an un-oriented plane consisting only of an origin and a normal. Note: Never use the struct default constructor PPlane() as it will create an invalid zero length PPlane. Use PPlane.create or PPlane.createUnchecked instead.

Record fields

Record Field Description

OriginX

Full Usage: OriginX

Field type: float

The X coordinate of the Origin 3D point of this PPlane.

Field type: float

OriginY

Full Usage: OriginY

Field type: float

The Y coordinate of the Origin 3D point of this PPlane.

Field type: float

OriginZ

Full Usage: OriginZ

Field type: float

The Z coordinate of the Origin 3D point of this PPlane.

Field type: float

XaxisX

Full Usage: XaxisX

Field type: float

The X component of the local X-axis unit vector of this PPlane.

Field type: float

XaxisY

Full Usage: XaxisY

Field type: float

The Y component of the local X-axis unit vector of this PPlane.

Field type: float

XaxisZ

Full Usage: XaxisZ

Field type: float

The Z component of the local X-axis unit vector of this PPlane.

Field type: float

YaxisX

Full Usage: YaxisX

Field type: float

The X component of the local Y-axis unit vector of this PPlane.

Field type: float

YaxisY

Full Usage: YaxisY

Field type: float

The Y component of the local Y-axis unit vector of this PPlane.

Field type: float

YaxisZ

Full Usage: YaxisZ

Field type: float

The Z component of the local Y-axis unit vector of this PPlane.

Field type: float

ZaxisX

Full Usage: ZaxisX

Field type: float

The X component of the local Z-axis unit vector of this PPlane.

Field type: float

ZaxisY

Full Usage: ZaxisY

Field type: float

The Y component of the local Z-axis unit vector of this PPlane.

Field type: float

ZaxisZ

Full Usage: ZaxisZ

Field type: float

The Z component of the local Z-axis unit vector of this PPlane.

Field type: float

Instance members

Instance member Description

this.AsFSharpCode

Full Usage: this.AsFSharpCode

Returns: string

Format PPlane into an F# code string that can be used to recreate the plane.

Returns: string

this.AsString

Full Usage: this.AsString

Returns: string

Format PPlane into string with nicely formatted floating point numbers. But without type name as in pl.ToString()

Returns: string

this.Origin

Full Usage: this.Origin

Returns: Pnt
Modifiers: inline

Creates a 3D point from the Origin coordinates of this PPlane.

Returns: Pnt

this.Xaxis

Full Usage: this.Xaxis

Returns: UnitVec
Modifiers: inline

Creates the local X-axis unit vector of this PPlane.

Returns: UnitVec

this.Yaxis

Full Usage: this.Yaxis

Returns: UnitVec
Modifiers: inline

Creates the local Y-axis unit vector of this PPlane.

Returns: UnitVec

this.Zaxis

Full Usage: this.Zaxis

Returns: UnitVec
Modifiers: inline

Creates the local Z-axis unit vector of this PPlane.

Returns: UnitVec

Static members

Static member Description

PPlane.asString pl

Full Usage: PPlane.asString pl

Parameters:
Returns: string
Modifiers: inline

Format PPlane into string with nicely formatted floating point numbers. But without type name as in pl.ToString()

pl : PPlane
Returns: string

PPlane.createUnchecked (originX, originY, originZ, xAxisX, xAxisY, xAxisZ, yAxisX, yAxisY, yAxisZ, zAxisX, zAxisY, zAxisZ)

Full Usage: PPlane.createUnchecked (originX, originY, originZ, xAxisX, xAxisY, xAxisZ, yAxisX, yAxisY, yAxisZ, zAxisX, zAxisY, zAxisZ)

Parameters:
    originX : float
    originY : float
    originZ : float
    xAxisX : float
    xAxisY : float
    xAxisZ : float
    yAxisX : float
    yAxisY : float
    yAxisZ : float
    zAxisX : float
    zAxisY : float
    zAxisZ : float

Returns: PPlane
Modifiers: inline

Unsafe internal constructor, doesn't check if the input is perpendicular or unitized. Requires correct input of unitized perpendicular vector components.

originX : float
originY : float
originZ : float
xAxisX : float
xAxisY : float
xAxisZ : float
yAxisX : float
yAxisY : float
yAxisZ : float
zAxisX : float
zAxisY : float
zAxisZ : float
Returns: PPlane

PPlane.createUncheckedVec (origin, axisX, axisY, axisZ)

Full Usage: PPlane.createUncheckedVec (origin, axisX, axisY, axisZ)

Parameters:
Returns: PPlane
Modifiers: inline

Unsafe internal constructor, doesn't check if the input is perpendicular. Requires correct input of unitized perpendicular vectors.

origin : Pnt
axisX : UnitVec
axisY : UnitVec
axisZ : UnitVec
Returns: PPlane

Type something to start searching.