PPlaneJsonConverter Type
Serializes a PPlane as its origin and axis components with System.Text.Json.
Constructors
| Constructor |
Description
|
|
|
Serializes a PPlane as its origin and axis components with System.Text.Json.
| Constructor |
Description
|
|
|