PtJsonConverter Type
Serializes a Pt as its X and Y coordinates with System.Text.Json.
Constructors
| Constructor |
Description
|
|
|
Serializes a Pt as its X and Y coordinates with System.Text.Json.
| Constructor |
Description
|
|
|