Rect3DJsonConverter Type
Serializes a Rect3D as its origin and axis components with System.Text.Json.
Constructors
| Constructor |
Description
|
|
|
Serializes a Rect3D as its origin and axis components with System.Text.Json.
| Constructor |
Description
|
|
|