Logo Euclid

GroupInsideObjectToCheck Type

A type used inside ObjectToCheck. It represent a group of similar input. The 'category' string is used to only compare groups of the same category. The 'bounding rectangle' of the points is used as a fast and first check for similarity. Within one 'list of points' the order does not matter, but each location must exist only once in order to be consider similar within the tolerance with another GroupInsideObjectToCheck.

Record fields

Record Field Description

bRect

Full Usage: bRect

Field type: BRect

The bounding rectangle used for the initial similarity check.

Field type: BRect

category

Full Usage: category

Field type: string

The category used to restrict comparisons to matching groups.

Field type: string

points

Full Usage: points

Field type: Pt[]

The points in the group, sorted by their X coordinate for binary search.

Field type: Pt[]

Type something to start searching.