Logo Euclid

ObjectToCheck Type

A type to represent on object that shall be compared to other objects. 'extend' (just a 2D point) represents the max value of a bounding rectangle, min value must be x=0 and y=0. This is used for a very fast initial similarity check. 'groups' (an array of GroupInsideObjectToCheck) must be sorted by 'category' property.

Record fields

Record Field Description

extend

Full Usage: extend

Field type: Pt

The maximum X and Y extents; the minimum is expected to be (0, 0).

Field type: Pt

groups

Full Usage: groups

Field type: GroupInsideObjectToCheck[]

The groups to compare, sorted by their category.

Field type: GroupInsideObjectToCheck[]

Type something to start searching.