UnitVcJsonConverter Type
Serializes a UnitVc as its X and Y components with System.Text.Json.
Constructors
| Constructor |
Description
|
|
|
Serializes a UnitVc as its X and Y components with System.Text.Json.
| Constructor |
Description
|
|
|