VcJsonConverter Type
Serializes a Vc as its X and Y components with System.Text.Json.
Constructors
| Constructor |
Description
|
|
|
Serializes a Vc as its X and Y components with System.Text.Json.
| Constructor |
Description
|
|
|