VecJsonConverter Type
Serializes a Vec as its X, Y, and Z coordinates with System.Text.Json.
Constructors
| Constructor |
Description
|
|
|
Serializes a Vec as its X, Y, and Z coordinates with System.Text.Json.
| Constructor |
Description
|
|
|