Logo Euclid

ClParams Type

Describes the possible cases of the closest parameters between finite 2D lines.

Union cases

Union case Description

Apart(paramA, paramB)

Full Usage: Apart(paramA, paramB)

Parameters:
    paramA : float
    paramB : float

The lines are apart. Contains the parameters at their closest points. These parameters are in the range 0.0 to 1.0

paramA : float
paramB : float

Intersect(paramA, paramB)

Full Usage: Intersect(paramA, paramB)

Parameters:
    paramA : float
    paramB : float

The lines intersect. Contains the parameters at the intersection point for both lines. These parameters are in the range 0.0 to 1.0

paramA : float
paramB : float

Parallel(paramA, paramB)

Full Usage: Parallel(paramA, paramB)

Parameters:
    paramA : float
    paramB : float

The lines are parallel or coincident. Overlapping parallel lines can have many parameters of closest distance. Contains the parameters at the midpoint of the overlapping segment. These parameters are in the range 0.0 to 1.0

paramA : float
paramB : float

TooShortA

Full Usage: TooShortA

Line A is shorter than the given minimum length tolerance.

TooShortB

Full Usage: TooShortB

Line B is shorter than the given minimum length tolerance.

TooShortBoth

Full Usage: TooShortBoth

Both Lines are shorter than the given minimum length tolerance.

Instance members

Instance member Description

this.IsApart

Full Usage: this.IsApart

Returns: bool
Returns: bool

this.IsIntersect

Full Usage: this.IsIntersect

Returns: bool
Returns: bool

this.IsParallel

Full Usage: this.IsParallel

Returns: bool
Returns: bool

this.IsTooShortA

Full Usage: this.IsTooShortA

Returns: bool
Returns: bool

this.IsTooShortB

Full Usage: this.IsTooShortB

Returns: bool
Returns: bool

this.IsTooShortBoth

Full Usage: this.IsTooShortBoth

Returns: bool
Returns: bool

Type something to start searching.