Logo Euclid

XLine3D Module

A module containing the result types for 3D Line-Line-Intersections, 3D Line-Line relationship queries, and Line-Cone intersections.

Types

Type Description

ClParams

Describes the possible cases of the closest parameters between finite 3D lines.

ClPts

Describes the possible cases of the closest points between finite 3D lines.

XCone

Result of intersecting an infinite line with one nappe of an infinite cone (only the part of the cone on the base side of the tip, not the mirrored double cone). All parameters are in the parametrization of the line: t=0 at ray.From, t=1 at ray.To, values outside 0..1 (including negative ones) lie on the infinite extension.

XEnds

Describes the possible cases of two finite 3D lines touching at their ends. Does not check if they are parallel or intersecting.

XParam

Describes the possible relationships of two finite 3D lines. Returns parameters on both lines if they intersect or are skew.

XPnt

Describes the possible relationships of two finite 3D lines. Returns the intersection or closest point if they intersect or are skew.

XRay

Describes the possible relationships of two rays (rays are 3D lines extended infinitely in both directions). Returns the intersection or closest point if they intersect or are skew.

XRayParam

Describes the possible relationships of two rays (rays are 3D lines extended infinitely in both directions). Returns parameters on both lines if they intersect or are skew.

Type something to start searching.