AutoOpenPnt Module
When Euclid is opened this module will be auto-opened. It only contains extension members for type Pnt.
Type extensions
| Type extension |
Description
|
|
|
|
|
|
|
|
|
|
Returns the Diamond Angle from this point to another point projected in X-Y plane. The diamond angle is always positive and in the range of 0.0 to 4.0 (for 360 Degrees) 0.0 = Xaxis, going Counter-Clockwise. Ignoring Z component. This is the fastest angle computation since it does not use Math.Cos or Math.Sin. It is useful for radial sorting.
Extended Type:
|
Full Usage:
this.DistanceFromOrigin
Parameters:
unit
Returns: float
Modifiers: inline |
|
Full Usage:
this.DistanceInXYFromOrigin
Parameters:
unit
Returns: float
Modifiers: inline |
Returns the projected distance from Origin (0, 0, 0). Ignoring the Z component.
Extended Type:
|
Full Usage:
this.DistanceInXYFromOriginSquare
Parameters:
unit
Returns: float
Modifiers: inline |
Returns the projected squared distance from Origin (0, 0, 0). Ignoring the Z component.
Extended Type:
|
|
|
|
|
Full Usage:
this.DistanceToXYZ
Parameters:
float
y : float
z : float
Returns: float
Modifiers: inline |
Returns the distance between a 3D point and given x, y, z coordinates.
Extended Type:
|
Full Usage:
this.IsAlmostOrigin
Parameters:
float
Returns: bool
Modifiers: inline |
Returns a boolean indicating whether the absolute value of X, Y and Z is each less than the given tolerance.
Extended Type:
|
Full Usage:
this.IsInValid
Parameters:
unit
Returns: bool
Modifiers: inline |
Returns a boolean indicating whether X, Y or Z is NaN or Infinity.
Extended Type:
|
Full Usage:
this.IsNotOrigin
Parameters:
unit
Returns: bool
Modifiers: inline |
Returns a boolean indicating if any of X, Y and Z is not exactly 0.0.
Extended Type:
|
Full Usage:
this.IsOrigin
Parameters:
unit
Returns: bool
Modifiers: inline |
Returns a boolean indicating whether X, Y and Z are exactly 0.0.
Extended Type:
|
Full Usage:
this.IsValid
Parameters:
unit
Returns: bool
Modifiers: inline |
Returns a boolean indicating whether X, Y and Z are valid (not NaN or Infinity).
Extended Type:
|
Full Usage:
this.SqDistanceFromOrigin
Parameters:
unit
Returns: float
Modifiers: inline |
|
|
|
|
|
Full Usage:
this.SqDistanceToXYZ
Parameters:
float
y : float
z : float
Returns: float
Modifiers: inline |
Returns the squared distance between a 3D point and given x, y, z coordinates.
Extended Type:
|
|
|
|
Multiplies (or applies) a RigidMatrix to a 3D point.
Extended Type:
|
Full Usage:
this.TransformRigidRotateOnly
Parameters:
RigidMatrix
Returns: Pnt
Modifiers: inline |
Multiplies (or applies) only the 3x3 rotation part of a RigidMatrix to a 3D point.
Extended Type:
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
Pnt.createFromMembersXYZ pt
Parameters:
^T
Returns: Pnt
Modifiers: inline Type parameters: ^T, ^a, ^b, ^c (requires (member get_X : ^T -> ^a) and (member get_Y : ^T -> ^b) and (member get_Z : ^T -> ^c) and (static member op_Explicit : ^a -> Microsoft.FSharp.Core.float) and (static member op_Explicit : ^b -> Microsoft.FSharp.Core.float) and (static member op_Explicit : ^c -> Microsoft.FSharp.Core.float)) |
|
Full Usage:
Pnt.createFromMembersxyz pt
Parameters:
^T
Returns: Pnt
Modifiers: inline Type parameters: ^T, ^a, ^b, ^c (requires (member get_x : ^T -> ^a) and (member get_y : ^T -> ^b) and (member get_z : ^T -> ^c) and (static member op_Explicit : ^a -> Microsoft.FSharp.Core.float) and (static member op_Explicit : ^b -> Microsoft.FSharp.Core.float) and (static member op_Explicit : ^c -> Microsoft.FSharp.Core.float)) |
|
|
|
|
|
|
|
|
|
|
Returns the Diamond Angle from 'fromPt' to 'toPt' projected in X-Y plane. The diamond angle is always positive and in the range of 0.0 to 4.0 (for 360 Degrees) 0.0 = Xaxis, going Counter-Clockwise. Ignoring Z component. This is the fastest angle computation since it does not use Math.Cos or Math.Sin. It is useful for radial sorting.
Extended Type:
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
Pnt.distanceInXYFromOriginSquare pt
Parameters:
Pnt
Returns: float
Modifiers: inline |
|
|
|
|
|
Full Usage:
Pnt.distanceToXYZ (x, y, z) p
Parameters:
float
y : float
z : float
p : Pnt
Returns: float
Modifiers: inline |
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
Pnt.isAlmostOrigin tol pt
Parameters:
float
pt : Pnt
Returns: bool
Modifiers: inline |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
For three Points describing a plane return a normal. The points 'a', 'b' and 'c' in counter-clockwise order return a normal pointing towards the viewer (e.g. +Z for points in the XY plane), matching NPlane.createFrom3Points and Points3D.normalOfPoints. The result is not unitized. If the returned vector has length zero then the points are in one line.
Extended Type:
|
|
|
|
|
|
|
Full Usage:
Pnt.projectedParameter (fromPt, uv, testPt)
Parameters:
Pnt
-
The origin point of the endless line.
uv : UnitVec
-
The unit direction vector describing the orientation of the endless line.
testPt : Pnt
-
The point to be projected onto the line.
Returns: float
The parameter (scalar value) along the unit vector at which the projection of testPt falls on the line.
Modifiers: inline |
Projects a test point onto an endless line defined by an origin point and a unit direction vector.
Extended Type:
|
Full Usage:
Pnt.projectedParameter (fromPt, v, testPt)
Parameters:
Pnt
-
The origin point of the endless line.
v : Vec
-
The direction vector of the endless line. Does not need to be unitized.
testPt : Pnt
-
The point to be projected onto the line.
Returns: float
The parameter (scaling factor for the direction vector) at which the projection of testPt falls on the line.
Modifiers: inline |
Projects a test point onto an endless line defined by an origin point and a direction vector.
Extended Type:
|
Full Usage:
Pnt.projectedParameter (fromPt, toPt, testPt)
Parameters:
Pnt
-
The start point defining the endless line.
toPt : Pnt
-
The end point defining the direction of the endless line.
testPt : Pnt
-
The point to be projected onto the line.
Returns: float
The parameter along the line direction (fromPt to toPt) at which the projection of testPt falls.
A value of 0.0 corresponds to fromPt, 1.0 corresponds to toPt.
Modifiers: inline |
Projects a test point onto an endless line defined by two points.
Extended Type:
|
|
|
|
Rotate the 3D point around X-axis, from Y to Z-axis, Counter Clockwise looking from right.
Extended Type:
|
|
|
Full Usage:
Pnt.rotateOnXWithCenter cen r pt
Parameters:
Pnt
r : Rotation2D
pt : Pnt
Returns: Pnt
|
Rotate the 3D point around a center 3D point and a X aligned axis, from Y to Z-axis, Counter Clockwise looking from right.
Extended Type:
|
|
|
|
Rotate the 3D point around Y-axis, from Z to X-axis, Counter Clockwise looking from back.
Extended Type:
|
|
|
Full Usage:
Pnt.rotateOnYWithCenter cen r pt
Parameters:
Pnt
r : Rotation2D
pt : Pnt
Returns: Pnt
|
Rotate the 3D point around a center point and a Y aligned axis, from Z to X-axis, Counter Clockwise looking from back.
Extended Type:
|
|
|
|
Rotate the 3D point around Z-axis, from X to Y-axis, Counter Clockwise looking from top.
Extended Type:
|
|
|
Full Usage:
Pnt.rotateOnZWithCenter cen r pt
Parameters:
Pnt
r : Rotation2D
pt : Pnt
Returns: Pnt
|
Rotate the 3D point around a center point and a Z aligned axis, from X to Y-axis, Counter Clockwise looking from top.
Extended Type:
|
|
|
Full Usage:
Pnt.rotateWithCenter cen q pt
Parameters:
Pnt
q : Quaternion
pt : Pnt
Returns: Pnt
Modifiers: inline |
Rotate by Quaternion around given center point.
Extended Type:
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
Pnt.sqDistanceToXYZ (x, y, z) p
Parameters:
float
y : float
z : float
p : Pnt
Returns: float
Modifiers: inline |
|
|
|
Full Usage:
Pnt.transformRigid m p
Parameters:
RigidMatrix
p : Pnt
Returns: Pnt
Modifiers: inline |
Multiplies (or applies) a RigidMatrix to a 3D point.
Extended Type:
|
|
Multiplies (or applies) only the 3x3 rotation part of a RigidMatrix to a 3D point.
Extended Type:
|
|
|
|
|
|
|
|
|
|
Euclid