FreeBox Type
A class containing an array of 8 points representing an arbitrary 3D Box-like topology. The points can be in arbitrary position in space.
7 6
+---------------+
/| /|
/ | / |
4 / | 5 / |
+---------------+ |
| | | |
| +-----------|---+
| / 3 | / 2
| / | /
|/ |/
+---------------+
0 1
Instance members
| Instance member |
Description
|
Full Usage:
this.AsFSharpCode
Returns: string
|
Format FreeBox into an F# code string that can be used to recreate the box.
|
Full Usage:
this.AsString
Returns: string
|
Nicely formatted string representation of the Box including Pt0.
|
|
Returns the edge between point 0 and point 1, E0 of the 12 box edges
|
|
Returns the edge between point 1 and point 2, E1 of the 12 box edges
|
|
Returns the edge between point 2 and point 6, E10 of the 12 box edges
|
|
Returns the edge between point 3 and point 7, E11 of the 12 box edges
|
|
Returns the edge between point 3 and point 2, E2 of the 12 box edges
|
|
Returns the edge between point 0 and point 3, E3 of the 12 box edges
|
|
Returns the edge between point 4 and point 5, E4 of the 12 box edges
|
|
Returns the edge between point 5 and point 6, E5 of the 12 box edges
|
|
Returns the edge between point 7 and point 6, E6 of the 12 box edges
|
|
Returns the edge between point 4 and point 7, E7 of the 12 box edges
|
|
Returns the edge between point 0 and point 4, E8 of the 12 box edges
|
|
Returns the edge between point 1 and point 5, E9 of the 12 box edges
|
|
Returns the 12 box edges.
|
|
|
|
|
|
|
|
|
|
The 8 points that make up the box.
|
Gets or sets the point 0 of the Box array.
|
|
Gets or sets the point 1 of the Box array.
|
|
Gets or sets the point 2 of the Box array.
|
|
Gets or sets the point 3 of the Box array.
|
|
Gets or sets the point 4 of the Box array.
|
|
Gets or sets the point 5 of the Box array.
|
|
Gets or sets the point 6 of the Box array.
|
|
Gets or sets the point 7 of the Box array.
|
|
|
Multiplies (or applies) a Quaternion to the FreeBox. The box is rotated around the World Origin.
|
|
Multiplies (or applies) a Quaternion to the FreeBox around a given center point.
|
|
|
|
|
|
|
|
|
|
Static members
| Static member |
Description
|
|
Format FreeBox into an F# code string that can be used to recreate the box.
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
FreeBox.rotate q b
Parameters:
Quaternion
b : FreeBox
Returns: FreeBox
Modifiers: inline |
Multiplies (or applies) a Quaternion to the FreeBox. The box is rotated around the World Origin.
|
Full Usage:
FreeBox.rotateWithCenter cen q b
Parameters:
Pnt
q : Quaternion
b : FreeBox
Returns: FreeBox
Modifiers: inline |
Multiplies (or applies) a Quaternion to the FreeBox around a given center point.
|
|
|
|
|
|
|
|
Nicely formatted string representation of the Box including Pt0 and Pt7.
|
|
|
Full Usage:
FreeBox.transformRigid m b
Parameters:
RigidMatrix
b : FreeBox
Returns: FreeBox
Modifiers: inline |
|
|
Euclid