NPlane Type
A struct containing a point and a unit normal, representing an unparametrized plane defined by a point and a normal vector. As opposed to the PPlane, this plane is not parametrized in X, Y, and Z directions. Internally it is stored as 6 floats (the Origin point coordinates and the normal vector components), just like the PPlane type. The Origin and Normal properties reconstruct the Pnt and UnitVec on demand. Note: Never use the struct default constructor NPlane() as it will create an invalid zero plane. Use NPlane.create or NPlane.createUnchecked instead.
Record fields
| Record Field |
Description
|
Full Usage:
NormalX
Field type: float
|
The X component of the normal unit vector of this NPlane.
|
Full Usage:
NormalY
Field type: float
|
The Y component of the normal unit vector of this NPlane.
|
Full Usage:
NormalZ
Field type: float
|
The Z component of the normal unit vector of this NPlane.
|
Full Usage:
OriginX
Field type: float
|
The X coordinate of the Origin 3D point of this NPlane.
|
Full Usage:
OriginY
Field type: float
|
The Y coordinate of the Origin 3D point of this NPlane.
|
Full Usage:
OriginZ
Field type: float
|
The Z coordinate of the Origin 3D point of this NPlane.
|
Constructors
| Constructor |
Description
|
|
Instance members
| Instance member |
Description
|
|
Returns the angle to a Line3D in degrees, ignoring the normal's orientation. So 0.0 if the line is parallel to the plane, and 90 degrees if the line is perpendicular to the plane.
|
|
Returns the angle to another plane in degrees, ignoring the normal's orientation. So 0.0 if the planes are parallel, and 90 degrees if the planes are perpendicular to each other.
|
|
Returns the angle to 3D unit-vector in degrees, ignoring the plane's orientation. So 0.0 if the vector is parallel to the plane, and 90 degrees if the vector is perpendicular to the plane.
|
|
Returns the angle to 3D vector in degrees, ignoring the plane's orientation. So 0.0 if the vector is parallel to the plane, and 90 degrees if the vector is perpendicular to the plane.
|
Full Usage:
this.AsFSharpCode
Returns: string
|
Format NPlane into an F# code string that can be used to recreate the plane.
|
Full Usage:
this.AsString
Returns: string
|
Format NPlane into string with nicely formatted floating point numbers. But without type name as in pl.ToString()
|
|
|
|
|
|
Returns signed distance of point to plane, also indicating on which side it is.
|
Full Usage:
this.DistanceToXYZ
Parameters:
float
y : float
z : float
Returns: float
Modifiers: inline |
Returns absolute distance of point to plane.
|
Full Usage:
this.DistanceToXYZSigned
Parameters:
float
y : float
z : float
Returns: float
Modifiers: inline |
Returns signed distance of point to plane, also indicating on which side it is.
|
|
Returns a new plane with the same Origin but flipped Normal.
|
Full Usage:
this.IsCoincidentTo
Parameters:
NPlane
?distanceTolerance : float
?minCosine : MeasureProduct<cosine, MeasureOne>
Returns: bool
Modifiers: inline |
Checks if two planes are coincident within the distance tolerance (1e-6 by default). This means that their normals are parallel within the angle tolerance and the distance of the second origin to the first plane is less than the distance tolerance. The default angle tolerance is 0.25 degrees. This tolerance can be customized by an optional minimum cosine value. See Euclid.Cosine module.
|
|
Creates the unitized normal vector of this NPlane.
|
|
Creates the Origin 3D point of this NPlane.
|
|
Static members
| Static member |
Description
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Format NPlane into an F# code string that can be used to recreate the plane.
|
|
Format NPlane into string with nicely formatted floating point numbers. But without type name as in pl.ToString()
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
NPlane.createUnchecked (originX, originY, originZ, normalX, normalY, normalZ)
Parameters:
float
originY : float
originZ : float
normalX : float
normalY : float
normalZ : float
Returns: NPlane
Modifiers: inline |
Unsafe internal constructor, doesn't check if the normal is unitized. Requires correct input of unitized normal vector components.
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
NPlane.distanceToXYZ x y z pl
Parameters:
float
y : float
z : float
pl : NPlane
Returns: float
Modifiers: inline |
Returns absolute distance of point to plane.
|
Full Usage:
NPlane.distanceToXYZSigned x y z pl
Parameters:
float
y : float
z : float
pl : NPlane
Returns: float
Modifiers: inline |
Returns signed distance of point to plane, also indicating on which side it is.
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Offsets the plane by the given distance in the direction determined by a point. If the point is on the positive side of the plane (same direction as normal), offsets in the normal direction. If the point is on the negative side, offsets in the opposite direction.
|
|
|
|
|
|
|
|
|
|
Gets the Plane at world origin with normal in world Z direction.
|
Euclid