CollinearPoint Type
For a point where the segments before and after are collinear, this structure holds the index of the point, and the indices of the previous and next points that have valid offset directions. `prevOK` may be bigger than `nextOK` if the collinear point is at the start or end of a closed polyline.
Record fields
| Record Field |
Description
|
Full Usage:
idx
Field type: int
|
The index of the collinear point.
|
Full Usage:
nextOK
Field type: int
|
The index of the following point with a valid offset direction.
|
Full Usage:
prevOK
Field type: int
|
The index of the preceding point with a valid offset direction.
|
Euclid