Points2D Type
A type containing only static member functions for operating on multiple 2D points or set of 2D points. Aka point-clouds
Static members
| Static member |
Description
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Find the index of the 2D point that has the biggest distance to any 2D point from the other set. Basically the most lonely point in 'findPointFrom' list with respect to 'checkAgainst' list. Returns findPointFromIdx * checkAgainstIdx
|
Euclid