PPlane Type
A struct containing one 3D point and three 3D unit vectors, representing an immutable parametrized plane or frame with unitized X, Y and Z Direction. Internally it is stored as 12 floats (the Origin point coordinates and the three axis vector components), just like the Box type. The Origin, Xaxis, Yaxis and Zaxis properties reconstruct the Pnt and UnitVec on demand. This struct is called 'PPlane'; the other plane 'NPlane' refers to an un-oriented plane consisting only of an origin and a normal. Note: Never use the struct default constructor PPlane() as it will create an invalid zero length PPlane. Use PPlane.create or PPlane.createUnchecked instead.
Record fields
| Record Field |
Description
|
Full Usage:
OriginX
Field type: float
|
The X coordinate of the Origin 3D point of this PPlane.
|
Full Usage:
OriginY
Field type: float
|
The Y coordinate of the Origin 3D point of this PPlane.
|
Full Usage:
OriginZ
Field type: float
|
The Z coordinate of the Origin 3D point of this PPlane.
|
Full Usage:
XaxisX
Field type: float
|
The X component of the local X-axis unit vector of this PPlane.
|
Full Usage:
XaxisY
Field type: float
|
The Y component of the local X-axis unit vector of this PPlane.
|
Full Usage:
XaxisZ
Field type: float
|
The Z component of the local X-axis unit vector of this PPlane.
|
Full Usage:
YaxisX
Field type: float
|
The X component of the local Y-axis unit vector of this PPlane.
|
Full Usage:
YaxisY
Field type: float
|
The Y component of the local Y-axis unit vector of this PPlane.
|
Full Usage:
YaxisZ
Field type: float
|
The Z component of the local Y-axis unit vector of this PPlane.
|
Full Usage:
ZaxisX
Field type: float
|
The X component of the local Z-axis unit vector of this PPlane.
|
Full Usage:
ZaxisY
Field type: float
|
The Y component of the local Z-axis unit vector of this PPlane.
|
Full Usage:
ZaxisZ
Field type: float
|
The Z component of the local Z-axis unit vector of this PPlane.
|
Instance members
| Instance member |
Description
|
Full Usage:
this.AsFSharpCode
Returns: string
|
Format PPlane into an F# code string that can be used to recreate the plane.
|
Full Usage:
this.AsString
Returns: string
|
Format PPlane into string with nicely formatted floating point numbers. But without type name as in pl.ToString()
|
|
Creates a 3D point from the Origin coordinates of this PPlane.
|
|
Creates the local X-axis unit vector of this PPlane.
|
|
Creates the local Y-axis unit vector of this PPlane.
|
|
Creates the local Z-axis unit vector of this PPlane.
|
Static members
| Static member |
Description
|
|
Format PPlane into string with nicely formatted floating point numbers. But without type name as in pl.ToString()
|
Full Usage:
PPlane.createUnchecked (originX, originY, originZ, xAxisX, xAxisY, xAxisZ, yAxisX, yAxisY, yAxisZ, zAxisX, zAxisY, zAxisZ)
Parameters:
float
originY : float
originZ : float
xAxisX : float
xAxisY : float
xAxisZ : float
yAxisX : float
yAxisY : float
yAxisZ : float
zAxisX : float
zAxisY : float
zAxisZ : float
Returns: PPlane
Modifiers: inline |
Unsafe internal constructor, doesn't check if the input is perpendicular or unitized. Requires correct input of unitized perpendicular vector components.
|
Euclid