ClParams Type
Describes the possible cases of the closest parameters between finite 2D lines.
Union cases
| Union case |
Description
|
Full Usage:
Apart(paramA, paramB)
Parameters:
float
paramB : float
|
The lines are apart. Contains the parameters at their closest points. These parameters are in the range 0.0 to 1.0
|
Full Usage:
Intersect(paramA, paramB)
Parameters:
float
paramB : float
|
The lines intersect. Contains the parameters at the intersection point for both lines. These parameters are in the range 0.0 to 1.0
|
Full Usage:
Parallel(paramA, paramB)
Parameters:
float
paramB : float
|
The lines are parallel or coincident. Overlapping parallel lines can have many parameters of closest distance. Contains the parameters at the midpoint of the overlapping segment. These parameters are in the range 0.0 to 1.0
|
Full Usage:
TooShortA
|
Line A is shorter than the given minimum length tolerance. |
Full Usage:
TooShortB
|
Line B is shorter than the given minimum length tolerance. |
Full Usage:
TooShortBoth
|
Both Lines are shorter than the given minimum length tolerance. |
Instance members
| Instance member |
Description
|
Full Usage:
this.IsApart
Returns: bool
|
|
Full Usage:
this.IsIntersect
Returns: bool
|
|
Full Usage:
this.IsParallel
Returns: bool
|
|
Full Usage:
this.IsTooShortA
Returns: bool
|
|
Full Usage:
this.IsTooShortB
Returns: bool
|
|
Full Usage:
this.IsTooShortBoth
Returns: bool
|
|
Euclid